@@ -17,6 +17,7 @@
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ***************************************************************************/
 
+#include "config.h"
 #include "sessionmodel.h"
 
 #include <QDir>
@@ -46,8 +47,8 @@ public:
 };
 
 SessionModel::SessionModel(QObject *parent) : QAbstractListModel(parent), d(new SessionModelPrivate()) {
-    loadDir(QStringLiteral("/usr/share/xsessions"), SessionTypeX);
-    loadDir(QStringLiteral("/usr/share/wayland-sessions"), SessionTypeWayland);
+    loadDir(QStringLiteral(XSESSIONS_DIR), SessionTypeX);
+    loadDir(QStringLiteral(WAYLAND_SESSIONS_DIR), SessionTypeWayland);
 }
 
 SessionModel::~SessionModel() {
@@ -57,7 +58,7 @@ SessionModel::~SessionModel() {
 void SessionModel::loadDir(const QString &path, SessionType type)
 {
     QDir dir(path);
-    dir.setNameFilters(QStringList() << QLatin1String("*.desktop"));
+    dir.setNameFilters(QStringList() << QStringLiteral("*.desktop"));
     dir.setFilter(QDir::Files);
     // read session
     foreach(const QString &session, dir.entryList()) {
